@@ -60,7 +60,6 @@ class Api:
         *,
         send_access_token: bool = False,
         send_project_auth: bool = False,
-        body_payload: Optional[Dict] = None,
         **kwargs,
     ) -> Response:
         """
@@ -69,38 +68,31 @@ class Api:
         :param name: Name of the method to call.
         """
 
-        # Build URL where API method is located.
-        api_server_method_url = f"{self._api_server_provider_url}/{name}"
-
-        get_params = kwargs.copy()
+        http_params = kwargs.copy()
         if send_access_token and self._auth_provider:
             if self._auth_provider.access_token:
-                get_params.update({"access_token": self._auth_provider.access_token})
+                http_params.update({"access_token": self._auth_provider.access_token})
 
         if send_project_auth and not send_access_token and self._auth_provider:
             if self._auth_provider.project_id:
-                get_params.update({"project_id": self._auth_provider.project_id})
+                http_params.update({"project_id": self._auth_provider.project_id})
             if self._auth_provider.server_secret:
-                get_params.update({"server_secret": self._auth_provider.server_secret})
+                http_params.update({"server_secret": self._auth_provider.server_secret})
             if (
                 self._auth_provider.client_secret
                 and not self._auth_provider.server_secret
             ):
-                get_params.update({"client_secret": self._auth_provider.client_secret})
+                http_params.update({"client_secret": self._auth_provider.client_secret})
+
+        # Build URL where API method is located.
+        api_server_method_url = f"{self._api_server_provider_url}/{name}"
 
         # Send HTTP request.
-        request_kwargs = {
-            "url": api_server_method_url,
-            "params": get_params,
-            "timeout": self._api_server_requests_timeout,
+        http_response = requests.get(
+            url=api_server_method_url,
+            params=http_params,
+            timeout=self._api_server_requests_timeout,
             **self._http_request_kwargs,
-        }
-        if body_payload:
-            request_kwargs["json"] = body_payload
-        http_response = (
-            requests.post(request_kwargs)
-            if body_payload
-            else requests.get(request_kwargs)
         )
 
         # Wrap HTTP response in to own Response object.
